@@ -14,7 +14,7 @@ use Data::Object::ClassHas;
 use SQL::Engine::Collection;
 use SQL::Validator;
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # ATTRIBUTES
 
@@ -350,6 +350,19 @@ method view_drop(@args) {
   return $self;
 }
 
+method union(@args) {
+  require SQL::Engine::Builder::Union;
+
+  my $grammar = SQL::Engine::Builder::Union->new(@args)->grammar(
+    grammar => $self->grammar,
+    validator => $self->validator
+  );
+
+  $self->operations->push($grammar->execute->operations->list);
+
+  return $self;
+}
+
 1;
 
 =encoding utf8
@@ -1090,6 +1103,55 @@ accepted by L<SQL::Engine::Builder::Transaction>.
 
 =cut
 
+=head2 union
+
+  union(Any %args) : Object
+
+The union method produces SQL operations which returns a results from two or
+more select queries. The arguments expected are the constructor arguments
+accepted by L<SQL::Engine::Builder::Union>.
+
+=over 4
+
+=item union example #1
+
+  # given: synopsis
+
+  $sql->operations->clear;
+
+  $sql->union(
+    queries => [
+      {
+        select => {
+          from => {
+            table => 'customers',
+          },
+          columns => [
+            {
+              column => 'name',
+            }
+          ]
+        }
+      },
+      {
+        select => {
+          from => {
+            table => 'employees',
+          },
+          columns => [
+            {
+              column => 'name',
+            }
+          ]
+        }
+      }
+    ]
+  );
+
+=back
+
+=cut
+
 =head2 update
 
   update(Any %args) : Object
@@ -2768,6 +2830,49 @@ syntax):
 
 =cut
 
+=head2 union
+
+=over 4
+
+=item union example #1
+
+  $sql->union(
+    queries => [
+      {
+        select => {
+          from => {
+            table => 'customers',
+          },
+          columns => [
+            {
+              column => 'name',
+            }
+          ]
+        }
+      },
+      {
+        select => {
+          from => {
+            table => 'employees',
+          },
+          columns => [
+            {
+              column => 'name',
+            }
+          ]
+        }
+      }
+    ]
+  );
+
+=item union example #1 output
+
+  # (SELECT "name" FROM "customers") UNION (SELECT "name" FROM "employees")
+
+=back
+
+=cut
+
 =head1 AUTHOR
 
 Al Newkirk, C<awncorp@cpan.org>
