@@ -17,7 +17,7 @@ use SQL::Validator;
 
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 # ATTRIBUTES
 
@@ -576,6 +576,9 @@ method expression(Any $data) {
 }
 
 method join_option(Maybe[Str] $name) {
+  if (!$name) {
+    return $self->term(qw(join));
+  }
   if (lc($name) eq "left-join") {
     return $self->term(qw(left join));
   }
@@ -748,6 +751,12 @@ method process(HashRef $schema = $self->schema) {
     return $self;
   }
 
+  if ($schema->{"union"}) {
+    $self->union($schema->{"union"});
+
+    return $self;
+  }
+
   return $self;
 }
 
@@ -1152,7 +1161,6 @@ method term(Str @args) {
 }
 
 method transaction(HashRef $data) {
-  $DB::single=1;
   $self->operation($self->term('begin', 'transaction'));
   $self->process($_) for @{$data->{queries}};
   $self->operation($self->term('commit'));
@@ -1555,6 +1563,31 @@ method view_drop(HashRef $data) {
   return $self->operation($result);
 }
 
+method union(HashRef $data) {
+  my $sql = [];
+
+  # union
+  my $type = $self->term('union');
+
+  # union type
+  if ($data->{type}) {
+    $type = join ' ', $type, $self->term($data->{type});
+  }
+
+  # union queries
+  for my $query (@{$data->{queries}}) {
+    $self->process($query);
+    my $operation = $self->operations->pop;
+    $self->{bindings} = $operation->bindings;
+    push @$sql, sprintf('(%s)', $operation->statement);
+  }
+
+  # sql statement
+  my $result = join " $type ", @$sql;
+
+  return $self->operation($result);
+}
+
 method wrap(Str $name) {
 
   return qq("$name");
